Learn R Programming

hyperdirichlet (version 1.3-8)

paulino: Dataset used by Paulino

Description

A hyperdirichlet distribution for the dataset considered by Paulino and de Braganca Pereira (1995).

Usage

data(paulino)

Arguments

source

C. D. M. Paulino and C. A. de Braganca Pereira 1995. Bayesian Methods for Categorical Data Under Informative General Censoring, Biometrika, volume 82, number 2, pages 439-446

Details

Paulino and de Braganca Pereiria considered 97 subjects who each were one of three risk types: low, medium, and high (or 1, 2, 3)

Of the 97 subjects, 51 were fully categorized: 14 were type 1, 17 type 2, and 20 type 3; the remaining 46 were partly categorized: 28 were of types 1 or 2, and 18 were of types 2 or 3.

The likelihood function is thus $$p_1^{14}p_2^{17}p_3^{20}\left(p_1+p_2\right)^{28}\left(p_2+p_3\right)^{18}$$ and object paulino gives the PDF.

Note the object gives the likelihood, not the posterior PDF. Paulino and de Branganca Pereira use prior information of a type not readily representable in the hyperdirichlet paradigm.

Examples

Run this code
data(paulino)
maximum_likelihood(paulino)

Run the code above in your browser using DataLab